@@ -15,7 +15,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 from mypvdevices.ServerConnection import ServerConnection
 from mypvdevices.Dataprocessor import Dataprocessor
 
-BUILDNR = "1.2112.7"
+BUILDNR = "1.2112.10"
 
 JOINTIMEOUTSECONDS = 5
 MONITORSLEEPTIMESECONDS = 10
@@ -254,22 +254,19 @@ class GeneralDevice:
                 self.readallregisters()
             except Exception as e:
                 logging.error(str(self._name) + ". Unknown BusCommunication register read error: " + str(e))
-                self._registers = None
-            if self._registers != None:
-                if len(self._registers) > 0:
-                    try:
-                        self._syncsettings()
-                    except Exception as e:
-                        logging.warning(str(self._name) + ". Settingssync not successfull. " + str(e))
-                else:
-                    logging.debug(str(self._name) + ". No bus communication to device.")
-                
+                self._registers = dict()
+            if len(self._registers) > 0:
                 try:
-                    self._processchannels()
+                    self._syncsettings()
                 except Exception as e:
-                    logging.warning(str(self._name) + ". processing registers not successfull. " + str(e))
+                    logging.warning(str(self._name) + ". Settingssync not successfull. " + str(e))
             else:
-                logging.debug(str(self._name) + ". No registers to process.")
+                logging.debug(str(self._name) + ". No bus communication to device.")
+            
+            try:
+                self._processchannels()
+            except Exception as e:
+                logging.warning(str(self._name) + ". processing registers not successfull. " + str(e))
 
     def _syncsettings(self):
         errors = 0
@@ -607,7 +604,10 @@ class GeneralDevice:
     def showinfo(self):
         if self._datasetdefinitions != None:
             for dataset in self._datasetdefinitions:
-                logging.info(str(self._name) + " " + dataset + ": Live: " + str(self.getchannelvalue(dataset)) + ", Log: " + str(self.getlogvalue(dataset)) + ", HealthState: " + str(self.gethealthstate()))
+                try:
+                    logging.info(str(self._name) + " " + dataset + ": Live: " + str(self.getchannelvalue(dataset)) + ", Log: " + str(self.getlogvalue(dataset)) + ", HealthState: " + str(self.gethealthstate()))
+                except Exception as e:
+                    logging.debug(str(self._name) + " Error printing deviceInfo. " + str(e))
         else:
             logging.debug(str(self._name) + " no datasets defined")
 
